%global _docdir_fmt %{name}

Name:		openvibe
Version:	1.1.0
Release:	10%{?dist}
Summary:	A software platform for brain-computer interfaces

License:	AGPLv3
URL:		http://openvibe.inria.fr

ExcludeArch:	armv7hl
# build fails on armv7hl because of the lack of float80 support #1322995

Source0:	http://openvibe.inria.fr/pub/src/%{name}-%{version}-src.tar.bz2
Source1:	openvibe-acquisition-server.desktop
Source2:	openvibe-designer.desktop
Source3:	openvibe-vrpn-simulator.desktop
Source4:	openvibe-skeleton-generator.desktop
Source5:	openvibe-acquisition-server.appdata.xml
Source6:	openvibe-designer.appdata.xml
Source7:	openvibe-skeleton-generator.appdata.xml

Patch0:		openvibe-include-fix.patch
Patch1:		openvibe-getline_eof.patch
Patch2:		openvibe-lsl_append_child_value.patch
Patch3:		openvibe-no_sse2.patch

BuildRequires:  gcc-c++
BuildRequires:	appdata-tools
BuildRequires:	boost-devel
BuildRequires:	cegui-devel
BuildRequires:	cmake
BuildRequires:	desktop-file-utils
BuildRequires:	doxygen
BuildRequires:	eigen3-devel
BuildRequires:	fftw-devel
BuildRequires:	freealut-devel
BuildRequires:	gcc
BuildRequires:	gtk2-devel
BuildRequires:	liblsl-devel
BuildRequires:	libvorbis-devel
BuildRequires:	lua-devel
BuildRequires:	ois-devel
BuildRequires:	ogre-devel
BuildRequires:	python2-devel
BuildRequires:	vrpn-devel

Requires:		%{name}-data = %{version}-%{release}
Requires(post):		desktop-file-utils
Requires(postun):	desktop-file-utils

%description
OpenViBE is a software platform dedicated to designing, testing and using
brain-computer interfaces.

OpenViBE is a software for real-time neurosciences (that is, for real-time
processing of brain signals). It can be used to acquire, filter, process,
classify and visualize brain signals in real time.


%package data
Summary:	OpenViBE data files
BuildArch:	noarch

%description data
OpenViBE is a software platform dedicated to designing, testing and using
brain-computer interfaces.

This package contains architecture independent data files for OpenViBE.


%package devel
Summary:	Development files for OpenViBE
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description devel
OpenViBE is a software platform dedicated to designing, testing and using
brain-computer interfaces.

This package contains development files for OpenViBE.


%package developer-tools
Summary:	Tools for OpenViBE plugin developers
Recommends:	%{name}-devel = %{version}-%{release}

%description developer-tools
OpenViBE is a software platform dedicated to designing, testing and using
brain-computer interfaces.

This package contains tools helping in OpenViBE plugin development.


%prep
%autosetup -n %{name}-%{version}-src -p1
find . -type f \( -name '*.h' -o -name '*.cpp' \) -exec chmod 644 {} +
iconv -f latin1 -t utf8 AUTHORS > AUTHORS.utf8 
mv AUTHORS.utf8 AUTHORS


%build
mkdir build
pushd build

CXXFLAGS='%optflags -std=c++98'; export CXXFLAGS
%cmake \
    -DCMAKE_INSTALL_INCLUDEDIR=%{_includedir}/%{name} \
    ..
%make_build

popd


%install
pushd build
%make_install
popd

find %{buildroot} -type f -name '*.sh' ! -executable -exec chmod 755 {} +

install -d -m755 %{buildroot}%{_datadir}/applications
install -m644 -t %{buildroot}%{_datadir}/applications \
    %{SOURCE1} \
    %{SOURCE2} \
    %{SOURCE3} \
    %{SOURCE4}

install -d -m755 %{buildroot}%{_datadir}/appdata
install -m644 -t %{buildroot}%{_datadir}/appdata \
    %{SOURCE5} \
    %{SOURCE6} \
    %{SOURCE7}


%check
# openvibe tests want matlab :(
desktop-file-validate %{buildroot}%{_datadir}/applications/*.desktop
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/appdata/*


%post
/sbin/ldconfig
/usr/bin/update-desktop-database &> /dev/null || :


%postun
/sbin/ldconfig
/usr/bin/update-desktop-database &> /dev/null || :


%files
%doc AUTHORS README
%exclude %{_prefix}/*.sh
%exclude %{_bindir}/test_*
%exclude %{_bindir}/*example*
%exclude %{_bindir}/openvibe-convert-real.sh
%{_bindir}/openvibe-acquisition-server
%{_bindir}/openvibe-designer
%{_bindir}/openvibe-external-application-launcher
%{_libdir}/*.so.*
%{_datadir}/applications/openvibe-acquisition-server.desktop
%{_datadir}/applications/openvibe-designer.desktop
%{_datadir}/appdata/openvibe-acquisition-server.appdata.xml
%{_datadir}/appdata/openvibe-designer.appdata.xml

%files data
%license COPYING
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/applications
%{_datadir}/%{name}/applications/acquisition-server
%{_datadir}/%{name}/applications/designer
%{_datadir}/%{name}/electrode_sets
%{_datadir}/%{name}/kernel
%{_datadir}/%{name}/plugins
%{_datadir}/%{name}/scenarios
%{_datadir}/%{name}/openvibe-ogre-plugins.cfg

%files devel
%{_libdir}/*.so
%{_includedir}/%{name}

%files developer-tools
%{_bindir}/openvibe-id-generator
%{_bindir}/openvibe-plugin-inspector
%{_bindir}/openvibe-skeleton-generator
%{_bindir}/openvibe-vrpn-simulator
%{_datadir}/applications/openvibe-skeleton-generator.desktop
%{_datadir}/applications/openvibe-vrpn-simulator.desktop
%{_datadir}/appdata/openvibe-skeleton-generator.appdata.xml
%{_datadir}/%{name}/applications/skeleton-generator
%{_datadir}/%{name}/applications/vrpn-simulator


%changelog
* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.0-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Mon Jun 18 2018 Dmitry Mikhirev <mikhirev@gmail.com> 1.1.0-9
- Rebuild with updated deps #1556089

* Thu Feb 08 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.0-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.0-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Jul 21 2017 Kalev Lember <klember@redhat.com> - 1.1.0-5
- Rebuilt for Boost 1.64

* Wed Feb 08 2017 Kalev Lember <klember@redhat.com> - 1.1.0-4
- Rebuilt for Boost 1.63

* Wed Dec 28 2016 Rich Mattes <richmattes@gmail.com> - 1.1.0-3
- Rebuild for eigen3-3.3.1

* Tue May 17 2016 Jonathan Wakely <jwakely@redhat.com> - 1.1.0-2
- Rebuilt for linker errors in boost (#1331983)

* Sun Feb 28 2016 Dmitry Mikhirev <mikhirev@gmail.com> 1.1.0-1
- Initial package
